Documentation
¶
Index ¶
- type Cache
- func (c *Cache) Close()
- func (c *Cache) Delete(key string) error
- func (c *Cache) Get(key string) ([]byte, error)
- func (c *Cache) GetString(key string) (string, error)
- func (c *Cache) GetValue(key string, value interface{}) error
- func (c *Cache) Has(key string) bool
- func (c *Cache) Set(key string, value []byte) error
- func (c *Cache) SetString(key, value string) error
- func (c *Cache) SetValue(key string, value interface{}) error
- type Option
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
func (*Cache) GetString ¶
GetString retrieves a value from the cache using the provided key and returns it as a string.
type Option ¶ added in v0.0.3
func WithCleanWindow ¶ added in v0.0.3
func WithContext ¶ added in v0.0.3
WithContext allows setting a custom context for the BigCache instance.
func WithLifeWindow ¶ added in v0.0.3
Click to show internal directories.
Click to hide internal directories.